pub fn ensure_server_config_fips_compliant(
config: &mut ServerConfig,
) -> Result<(), GenericError>Expand description
Ensures that a server TLS configuration is FIPS compliant.
In FIPS builds, this disables operational secret extraction settings and checks the Rustls FIPS marker on the configuration. In non-FIPS builds, this is a no-op.
Errors
If FIPS support is enabled and the configuration is not FIPS compliant, an error is returned.