initialize_default_crypto_provider

Function initialize_default_crypto_provider 

pub fn initialize_default_crypto_provider() -> Result<(), GenericError>
Initializes the default TLS cryptography provider used by rustls.

This explicitly sets the platform default provider for all future TLS configurations: CNG on Windows and AWS-LC on other platforms. FIPS builds configure the selected platform provider for FIPS mode.

Errors

If the default cryptography provider has already been set, an error will be returned.