ClientTLSConfigBuilder

Struct ClientTLSConfigBuilder 

pub struct ClientTLSConfigBuilder { /* private fields */ }
A TLS client configuration builder.

Exposes various options for configuring a client’s TLS configuration that would otherwise be cumbersome to configure, and provides sane defaults for many common options.

Missing

  • ability to configure client authentication

Implementations

Source

impl ClientTLSConfigBuilder

pub fn new() -> Self

pub fn with_key_log_file<P: Into<PathBuf>>(self, path: P) -> Self

Enables logging of TLS key material to the given file path.

TLS key material will be logged to the given file path in the NSS Key Log format, which can be used for debugging TLS issues, as well as decrypting captured TLS traffic in tools such as Wireshark.

Newly created files are created with owner read/write permissions on Unix. Existing file permissions are preserved.

pub fn with_max_tls12_resumption_sessions(self, max: usize) -> Self

Sets the maximum number of TLS 1.2 sessions to cache.

Defaults to 8.

pub fn with_root_cert_store(self, store: RootCertStore) -> Self

Sets the root certificate store to use for the client.

Defaults to the “default” root certificate store initialized from the platform. (See load_platform_root_certificates.)

pub fn with_min_tls_version(self, version: TlsMinimumVersion) -> Self

Sets the minimum TLS protocol version to allow for client connections.

Defaults to TLS 1.2.

pub fn danger_accept_invalid_certs(self) -> Self

Disables server certificate verification entirely.

This is inherently insecure and should only be used for local/development connections where the server’s identity is already established through other means (for example, connecting via Unix domain socket to a local process).

pub fn build(self) -> Result<ClientConfig, GenericError>

Builds the client TLS configuration.

Errors

If the default root cert store (see load_platform_root_certificates) hasn’t been initialized, and a root cert store hasn’t been provided, or if the resulting configuration isn’t FIPS compliant, an error will be returned.